@@ -1261,9 +1261,9 @@ void handle_request_result(t_session *session, int result) {
 				}
 #endif
 			}
-			session->return_code = 400;
+			session->return_code = 409;
 			send_code(session);
-			log_request(session, 400);
+			log_request(session, session->return_code);
 			break;
 		default:
 			if (session->data_sent == false) {
@@ -2108,6 +2108,10 @@ int run_server(t_settings *settings) {
 #ifdef HAVE_XSLT
 	init_xslt_module();
 #endif
+	if (init_sqli_detection() == -1) {
+		fprintf(stderr, "Error initializing SQL injection detection.\n");
+		return -1;
+	}
 #ifdef HAVE_MONITOR
 	if (config->monitor_enabled) {
 		if (init_monitor_module(config) == -1) {
