@@ -90,12 +90,12 @@ static int sync_monitor_buffer(void) {
 	}
 
 	snprintf(filename + filename_offset, MAX_FILENAME_SIZE, "%ld.txt.gz", time(NULL));
-	if ((handle = open(filename, O_CREAT | O_APPEND | O_WRONLY, 0640)) == -1) {
+	if ((handle = open(filename, O_CREAT | O_APPEND | O_WRONLY, S_IRUSR | S_IWUSR | S_IRGRP)) == -1) {
 		return -1;
 	}
-	fchmod(handle, 0600);
+	fchmod(handle, S_IRUSR | S_IWUSR);
 
-	if ((gzhandle = gzdopen(handle, "w9")) == NULL) {
+	if ((gzhandle = gzdopen(handle, "w6")) == NULL) {
 		close(handle);
 		unlink(filename);
 		return -1;
@@ -104,16 +104,18 @@ static int sync_monitor_buffer(void) {
 	total_written = 0;
 	while (total_written < monitor_buffer_size) {
 		if ((bytes_written = gzwrite(gzhandle, monitor_buffer + total_written, monitor_buffer_size - total_written)) == -1) {
-			gzclose(gzhandle);
-			close(handle);
+			if (gzclose(gzhandle) != Z_OK) {
+				close(handle);
+			}
 			unlink(filename);
 			return -1;
 		}
 		total_written += bytes_written;
 	}
 
-	gzclose(gzhandle);
-	close(handle);
+	if (gzclose(gzhandle) != Z_OK) {
+		close(handle);
+	}
 
 	monitor_buffer_size = 0;
 
@@ -176,6 +178,8 @@ int init_monitor_module(t_config *config) {
 /* Stop monitor module
  */
 void shutdown_monitor_module(t_config *config) {
+	stats_delay = 0;
+	monitor_stats(config, time(NULL));
 	sync_monitor_buffer();
 }
 
