@@ -47,7 +47,6 @@ typedef struct {
 	char       *pidfile;
 	char       *children;
 	char       *max_requests;
-	int        server_nr;
 	t_php_cgi  *php_cgi;
 	t_keyvalue *envir;
 } t_config;
@@ -285,7 +284,6 @@ t_config *read_config(char *config_file) {
 	config->pidfile = strdup(PIDFILE_DIR"/php-fcgi.pid");
 	config->children = strdup("3");
 	config->max_requests = strdup("100");
-	config->server_nr = -1;
 	config->php_cgi = NULL;
 	config->envir = NULL;
 
@@ -472,13 +470,6 @@ int main(int argc, char *argv[]) {
 	bool kill_servers = false;
 	int i = 0;
 
-	if ((config = read_config(config_file)) == NULL) {
-		return EXIT_FAILURE;
-	}
-	if (valid_config(config) == false) {
-		return EXIT_FAILURE;
-	}
-
 	while (++i < argc) {
 		if (strcmp(argv[i], "-c") == 0) {
 			if (++i < argc) {
@@ -494,13 +485,6 @@ int main(int argc, char *argv[]) {
 			kill_servers = true;
 		} else if (strcmp(argv[i], "-q") == 0) {
 			quiet = true;
-		} else if (strcmp(argv[i], "-s") == 0) {
-			if (++i < argc) {
-				config->server_nr = str2int(argv[i]);
-			} else {
-				fprintf(stderr, "Specify a server number.\n");
-				return EXIT_FAILURE;
-			}
 		} else if (strcmp(argv[i], "-v") == 0) {
 			printf("PHP-FastCGI v"VERSION"\n");
 			return EXIT_SUCCESS;
@@ -510,6 +494,13 @@ int main(int argc, char *argv[]) {
 		}
 	}
 
+	if ((config = read_config(config_file)) == NULL) {
+		return EXIT_FAILURE;
+	}
+	if (valid_config(config) == false) {
+		return EXIT_FAILURE;
+	}
+
 	if (kill_servers == false) {
 		if (start_fastcgi_servers(config) == -1) {
 			return EXIT_FAILURE;
