@@ -30,7 +30,23 @@
 #ifdef HAVE_COMMAND
 #include "command.h"
 #endif
+#include <regex.h>
 
+static const struct {
+	const char *text;
+} sqli_detection[] = {
+	{"union\\s*select"},
+	{"[\\s'0-9a-z]\\s*--\\s"},
+	{"'\\s*(and|or|&&|\\|\\|)\\s*('|[0-9]|[a-z.]*\\s*=)"},
+	{NULL}
+};
+
+typedef struct type_sqli_pattern {
+	regex_t regex;
+	struct type_sqli_pattern *next;
+} t_sqli_pattern;
+
+t_sqli_pattern *sqli_patterns = NULL;
 static int new_client_id = 0;
 
 /* Set the entries in a session-record to the default values.
@@ -523,63 +539,60 @@ int prevent_xss(t_session *session) {
 	return result;
 }
 
+/* Initialize SQL injection detection
+ */
+int init_sqli_detection(void) {
+	t_sqli_pattern *prev;
+	int i;
+
+	for (i = 0; sqli_detection[i].text != NULL; i++) {
+		prev = sqli_patterns;
+		if ((sqli_patterns = (t_sqli_pattern*)malloc(sizeof(t_sqli_pattern))) == NULL) {
+			return -1;
+		}
+		sqli_patterns->next = prev;
+
+		if (regcomp(&(sqli_patterns->regex), sqli_detection[i].text, REG_EXTENDED | REG_ICASE | REG_NOSUB) != 0) {
+			fprintf(stderr, "Error in regexp %s\n", sqli_detection[i].text);
+			return -1;
+		}
+	}
+
+	return 0;
+}
+
 /* Prevent SQL injection
  */
-int prevent_sqli(t_session *session, char *str, int length, char **newstr) {
-	int changed = 0, i, add, left, newlength = 0, extra_buffer = 128;
-	char *temp, value;
-	short low, high;
+int prevent_sqli(t_session *session, char *str, int length) {
+	char *data;
+	t_sqli_pattern *pattern;
 
-	if ((str == NULL) || (length == 0) || (newstr == NULL)) {
+	if ((str == NULL) || (length <= 0)) {
 		return 0;
 	}
 
-	add = left = extra_buffer;
-	if ((*newstr = (char*)malloc(length + add + 1)) == NULL) {
+	if ((data = (char*)malloc(length + 1)) == NULL) {
 		return -1;
 	}
-	for (i = 0; i < length; i++) {
-		value = *(str + i);
+	memcpy(data, str, length);
+	data[length] = '\0';
+	url_decode(data);
 
-		if ((value == '%') && (i + 2 < length)) {
-			if ((high = hex_to_int(*(str + i + 1))) != -1) {
-				if ((low = hex_to_int(*(str + i + 2))) != -1) {
-					value = (char)(high << 4) + low;
-				}
-			}
-		}
-
-		if ((value == '\'') || (value == '`') || (value == '\\')) {
-			if (changed++ == 0) {
-				log_exploit_attempt(session, "SQLi", session->vars);
-			}
-
-			*(*newstr + (newlength++)) = '\\';
-			if (--left == 0) {
-				add += left = extra_buffer;
-				if ((temp = (char*)realloc(*newstr, length + add + 1)) == NULL) {
-					free(*newstr);
-					return -1;
-				} else {
-					*newstr = temp;
-				}
-			}
-		}
-		*(*newstr + (newlength++)) = *(str + i);
-	}
-
-	if (changed == 0) {
-		free(*newstr);
-		*newstr = NULL;
-		newlength = 0;
-	} else {
-		*(*newstr + newlength) = '\0';
+	pattern = sqli_patterns;
+	while (pattern != NULL) {
+		if (regexec(&(pattern->regex), data, 0, NULL, 0) != REG_NOMATCH) {
+			log_exploit_attempt(session, "SQLi", str);
 #ifdef HAVE_MONITOR
-		monitor_counter_exploit_attempt(session);
+			monitor_counter_exploit_attempt(session);
 #endif
+
+			return 1;
+		}
+
+		pattern = pattern->next;
 	}
 
-	return newlength;
+	return 0;
 }
 
 /* Prevent Cross-site Request Forgery
