@@ -134,7 +134,8 @@ int  copy_directory_settings(t_session *session);
 bool client_is_rejected_bot(t_session *session);
 int  remove_port_from_hostname(char *hostname, t_binding *binding);
 int  prevent_xss(t_session *session);
-int  prevent_sqli(t_session *session, char *str, int length, char **newstr);
+int  init_sqli_detection(void);
+int  prevent_sqli(t_session *session, char *str, int length);
 int  prevent_csrf(t_session *session);
 void close_socket(t_session *session);
 
