@@ -553,64 +553,50 @@ int execute_cgi(t_session *session) {
 	if (session->host->prevent_sqli) {
 		/* Prevent SQL injection
 		 */
-		if (session->vars != NULL) {
-			switch (prevent_sqli(session, session->vars, strlen(session->vars), &line)) {
+		if (session->request_uri != NULL) {
+			switch (prevent_sqli(session, session->request_uri, strlen(session->request_uri))) {
 				case -1:
 					return 500;
 				case 0:
 					break;
 				default:
-					if (session->config->ban_on_sqli > 0) {
-						free(line);
-						session->error_cause = ec_SQL_INJECTION;
-						return -1;
-					}
-					if (register_tempdata(&(session->tempdata), line, tc_data) == -1) {
-						free(line);
-						return -1;
-					}
-					session->vars = line;
+					session->error_cause = ec_SQL_INJECTION;
+					return -1;
+			}
+		}
+		if (session->vars != NULL) {
+			switch (prevent_sqli(session, session->vars, strlen(session->vars))) {
+				case -1:
+					return 500;
+				case 0:
+					break;
+				default:
+					session->error_cause = ec_SQL_INJECTION;
+					return -1;
 			}
 		}
 
 		if (session->body != NULL) {
-			switch (result = prevent_sqli(session, session->body, session->content_length, &line)) {
+			switch (prevent_sqli(session, session->body, session->content_length)) {
 				case -1:
 					return 500;
 				case 0:
 					break;
 				default:
-					if (session->config->ban_on_sqli > 0) {
-						free(line);
-						session->error_cause = ec_SQL_INJECTION;
-						return -1;
-					}
-					if (register_tempdata(&(session->tempdata), line, tc_data) == -1) {
-						free(line);
-						return -1;
-					}
-					session->body = line;
-					session->content_length = result;
+					session->error_cause = ec_SQL_INJECTION;
+					return -1;
 			}
 		}
 
 		if (session->cookie != NULL) {
-			switch (prevent_sqli(session, session->cookie, strlen(session->cookie), &line)) {
+			switch (prevent_sqli(session, session->cookie, strlen(session->cookie))) {
 				case -1:
 					return 500;
 				case 0:
 					break;
 				default:
-					if (session->config->ban_on_sqli > 0) {
-						free(line);
-						session->error_cause = ec_SQL_INJECTION;
-						return -1;
-					}
-					if (register_tempdata(&(session->tempdata), line, tc_data) == -1) {
-						free(line);
-						return -1;
-					}
-					session->cookie = line;
+					session->error_cause = ec_SQL_INJECTION;
+					return -1;
 			}
 		}
 	}
