@@ -15,10 +15,19 @@
 #include <stdbool.h>
 #include <unistd.h>
 #include <string.h>
+#include <time.h>
+#include <termios.h>
+#ifdef HAVE_CRYPT_H
+#include <crypt.h>
+#endif
+#ifdef HAVE_RPCSVC_CRYPT_H
+#include <rpcsvc/crypt.h>
+#endif
 #include "global.h"
 #include "alternative.h"
 #include "libstr.h"
 #include "libfs.h"
+#include "libmd5.h"
 #ifdef HAVE_TOOLKIT
 #include "toolkit.h"
 #endif
@@ -651,7 +660,7 @@ void check_url_toolkit(char *config_dir, char **toolkit_id) {
 			printf("Bad URL: missing leading slash.\n");
 		}
 
-		init_toolkit_options(&options, ".", url_toolkit, false);
+		init_toolkit_options(&options, ".", url_toolkit, false, NULL);
 
 		id = toolkit_id;
 		while (*id != NULL) {
@@ -694,9 +703,71 @@ void check_url_toolkit(char *config_dir, char **toolkit_id) {
 }
 #endif
 
+void read_password(char *buffer, int size) {
+	struct termios tty;
+	int pos = 0;
+	char c;
+
+	printf("Enter password: ");
+
+	if (tcgetattr(STDOUT_FILENO, &tty) == -1) {
+		printf("Terminal error.\n");
+		return;
+	}
+	tty.c_lflag &= ~ECHO;
+	if (tcsetattr(STDOUT_FILENO, TCSADRAIN, &tty) == -1) {
+		printf("Terminal error.\n");
+		return;
+	}
+
+	while (((c = getc(stdin)) != '\n') && (pos < size - 1)) {
+		buffer[pos++] = c;
+	}
+
+	buffer[pos] = '\0';
+
+	printf("\n");
+}
+
+void create_basic_password(char *username) {
+	char password[100], salt[3], *encrypted;
+	char *salt_digits = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789./";
+	int len;
+
+	srand((unsigned)time(NULL));
+	len = strlen(salt_digits);
+
+	read_password(password, 100);
+	salt[0] = salt_digits[rand() % len];
+	salt[1] = salt_digits[rand() % len];
+	salt[2] = '\0';
+	encrypted = crypt(password, salt);
+
+	printf("%s:%s\n", username, encrypted);
+}
+
+void create_digest_password(char *username, char *realm) {
+	char password[100], *data, encrypted[33];
+
+	read_password(password, 100);
+
+	if ((data = (void*)malloc(strlen(username) + strlen(realm) + strlen(password) + 4)) == NULL) {
+		return;
+	}
+
+	sprintf(data, "%s:%s:%s", username, realm, password);
+	md5_hash(data, strlen(data), encrypted);
+
+	free(data);
+
+	printf("%s:%s:%s\n", username, realm, encrypted);
+}
+
 void show_help(char *wigwam) {
 	printf("Usage: %s [options]\n", wigwam);
-	printf("Options: -c <path>: path to where the configrationfiles are located.\n");
+	printf("Options: -b <username>: create password file entry for basic HTTP authentication\n");
+	printf("         -c <path>: path to where the configration files are located.\n");
+	printf("         -d <username> <realm>: create password file entry for digest HTTP authentication\n");
 	printf("         -h: show this information and exit.\n");
 	printf("         -q: don't print the test results.\n");
 #ifdef HAVE_TOOLKIT
@@ -710,13 +781,29 @@ int main(int argc, char *argv[]) {
 	char *config_dir = CONFIG_DIR;
 
 	for (i = 1; i < argc; i++) {
-		if (strcmp(argv[i], "-c") == 0) {
+		if (strcmp(argv[i], "-b") == 0) {
+			if (++i < argc) {
+				create_basic_password(argv[i]);
+				return EXIT_SUCCESS;
+			} else {
+				fprintf(stderr, "Specify a username.\n");
+				return EXIT_FAILURE;
+			}
+		} else if (strcmp(argv[i], "-c") == 0) {
 			if (++i < argc) {
 				config_dir = argv[i];
 			} else {
 				fprintf(stderr, "Specify a directory.\n");
 				return EXIT_FAILURE;
 			}
+		} else if (strcmp(argv[i], "-d") == 0) {
+			if (++i < argc - 1) {
+				create_digest_password(argv[i], argv[i + 1]);
+				return EXIT_SUCCESS;
+			} else {
+				fprintf(stderr, "Specify a username and a realm.\n");
+				return EXIT_FAILURE;
+			}
         } else if (strcmp(argv[i], "-h") == 0) {
 			show_help(argv[0]);
 			return EXIT_SUCCESS;
